#
# spec file for package kpipewire6
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global kf6_version 6.14.0
%define qt6_version 6.8.0

%define _sover 6
%define rname kpipewire
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %global _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kpipewire6
Version:        6.4.0
Release:        1.1
Summary:        PipeWire integration for KDE Plasma
License:        LGPL-2.0-only AND LGPL-3.0-only
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KWayland) >= %{_plasma6_version}
BuildRequires:  cmake(PlasmaWaylandProtocols)
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickTest) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6WaylandClient) >= %{qt6_version}
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-drm)

%description
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.

%package -n libKPipeWire%{_sover}
Summary:        PipeWire integration for KDE Plasma - main library

%description -n libKPipeWire%{_sover}
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.
This package contains the main KPipeWire library.

%package -n libKPipeWireRecord%{_sover}
Summary:        PipeWire integration for KDE Plasma - recording support

%description -n libKPipeWireRecord%{_sover}
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.
This package contains the library needed for video and audio capture.

%package -n libKPipeWireDmaBuf%{_sover}
Summary:        PipeWire integration for KDE Plasma - DMA-BUF support

%description -n libKPipeWireDmaBuf%{_sover}
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.
This package provides a helper for downloading DMA-BUF textures for CPU processing.

%package imports
Summary:        QtQuick bindings for kpipewire6
Requires:       libKPipeWire%{_sover} = %{version}
Requires:       libKPipeWireDmaBuf%{_sover} = %{version}
Requires:       libKPipeWireRecord%{_sover} = %{version}

%description imports
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.
This package provides QtQuick bindings for the main KPipeWire libraries.

%package devel
Summary:        Development files for kpipewire6
Requires:       kpipewire6-imports = %{version}
Requires:       libKPipeWire%{_sover} = %{version}
Requires:       libKPipeWireDmaBuf%{_sover} = %{version}
Requires:       libKPipeWireRecord%{_sover} = %{version}
Requires:       pkgconfig(epoxy)
Requires:       pkgconfig(libpipewire-0.3)
Conflicts:      kpipewire-devel

%description devel
KPipeWire provides PipeWire integration for the Plasma desktop and mobile shells.
This package provides the development files needed to build applications
which use KPipeWire.

%lang_package -n libKPipeWire%{_sover}

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang kpipewire6

%check
# Test fails since 03201bb6. A running pipewire is required
# %%ctest

%ldconfig_scriptlets -n libKPipeWire%{_sover}
%ldconfig_scriptlets -n libKPipeWireRecord%{_sover}
%ldconfig_scriptlets -n libKPipeWireDmaBuf%{_sover}

%files -n libKPipeWire%{_sover}
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKPipeWire.so.*
%{_kf6_debugdir}/kpipewire.categories

%files -n libKPipeWireRecord%{_sover}
%{_kf6_libdir}/libKPipeWireRecord.so.*
%{_kf6_debugdir}/kpipewirerecord.categories

%files -n libKPipeWireDmaBuf%{_sover}
%{_kf6_libdir}/libKPipeWireDmaBuf.so.*

%files imports
%{_kf6_qmldir}/org/kde/pipewire/

%files devel
%{_includedir}/KPipeWire/
%{_kf6_cmakedir}/KPipeWire/
%{_kf6_libdir}/libKPipeWire.so
%{_kf6_libdir}/libKPipeWireRecord.so
%{_kf6_libdir}/libKPipeWireDmaBuf.so

%files -n libKPipeWire%{_sover}-lang -f kpipewire6.lang

%changelog
* Thu Jun 12 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.4.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.4.0
- Changes since 6.3.91:
  * Update version for new release 6.4.0
* Thu May 29 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.91
- Changes since 6.3.90:
  * Update version for new release 6.3.91
  * cmake: also declare major, minor and patch version vars
  * cmake: use PROJECT_VERSION
* Mon May 19 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.3.90
- Changes since 6.3.5:
  * update project version to 6.3.90
  * tests: Drop versions in qml imports
  * Use qqmlintegration.h instead of qqmlregistration.h
  * Port to declarative type registration
  * encodedstream: Don't query VAAPI in the constructor
  * encodedstream: Deprecate setActive() and replace with an explicit API
  * It compiles fine without kf_6_12 deprecated methods
  * Tweak encoding options for VP9
  * Port Encoder away from deprecated avcodec_close
  * Set "threads" option by default in Encoder
  * Add logging of encoding options if log level is set to info
  * Change Encoder::applyEncodingPreference() to buildEncodingOptions() (kde#488896)
  * Tweak compiler warning flags to reduce unneeded output
  * Add logging that outputs number of processed and pending frames every second
  * sourceitem: invoke method with correct context object (kde#501042)
  * Use malloc to create AVDRMFrameDescriptor
  * CI: Add linux-qt6-next build
  * Add xml/yaml linting
  * Fix build with Qt 6.10
  * Add missing !
  * PipeWireSourceStream::setActive demote assert to warning
  * PipeWireSourceItem handle stream creation failure
  * update version for new release
* Tue May  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.5
- Changes since 6.3.4:
  * update version for new release
* Wed Apr  2 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.3.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/6/6.3.4
- Changes since 6.3.3:
  * update version for new release
* Tue Mar 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.3
- Changes since 6.3.2:
  * sourceitem: invoke method with correct context object (kde#501042)
  * update version for new release
* Tue Feb 25 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.2
- Changes since 6.3.1:
  * update version for new release
* Tue Feb 18 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.1
- Changes since 6.3.0:
  * Use malloc to create AVDRMFrameDescriptor
  * update version for new release
* Thu Feb  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.0
- Changes since 6.2.91:
  * update version for new release
* Thu Jan 23 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.91
- Changes since 6.2.90:
  * update version for new release
  * Add missing !
  * PipeWireSourceStream::setActive demote assert to warning
  * PipeWireSourceItem handle stream creation failure
* Sat Jan 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.2.90
- Changes since 6.2.5:
  * update version for new release
  * Use ECMDeprecationSettings
  * Avoid calling pipewire methods on the render thread
  * Flush encoder queue when streaming doesn't provide an update
  * Add GIF support
  * Add animated WebP support
  * Add metainfo.yaml
  * libx264encoder: Ensure stream size is always a multiple of 2 (kde#485733)
  * encoder: Make it possble to override the filter graph used for software encode
  * PipeWireCore: handle null loop from pw_loop_new gracefully
  * PipeWireSourceStream: work around crashes for pipewire < 0.3.49 (kde#492400)
  * produce: Flush remaining frames when we are deactivating (kde#471159)
  * update version for new release
  * h264vaapi: Use the proper getter for getting the hardware context
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * Flush encoder queue when streaming doesn't provide an update
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
  * libx264encoder: Ensure stream size is always a multiple of 2 (kde#485733)
  * encoder: Make it possble to override the filter graph used for software encode
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * update version for new release
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * PipeWireSourceStream: work around crashes for pipewire < 0.3.49 (kde#492400)
  * produce: Flush remaining frames when we are deactivating (kde#471159)
  * update version for new release
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
  * h264vaapi: Use the proper getter for getting the hardware context
* Thu Oct  3 2024 Christophe Marin <christophe@krop.fr>
- Drop patch, no longer needed:
  * 0001-h264vaapi-Use-the-proper-getter-for-getting-the-hard.patch
* Thu Oct  3 2024 Christophe Marin <christophe@krop.fr>
- Add ffmpeg 7.1 compatibility patch:
  * 0001-h264vaapi-Use-the-proper-getter-for-getting-the-hard.patch
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Changes since 6.1.5:
  * update version for new release
  * sourcestream: Do not process null streams
  * Add missing "pipewireencodedstream.h" include
  * Generate wayland code with PRIVATE_CODE
  * produce: Use a separate condition_variable for passthrough/output thread
  * Guard m_stream in setMaxFramerate
  * pipewireproduce.cpp: Add guard to m_stream
  * sourcestream: make resilient against pipewire restarts
  * Fix some copy-and-paste issues in h264vaapi and libx264 encoders
  * Add encoder using libopenh264 (kde#476187)
  * Simpler yet more useful handling of KPIPEWIRE_FORCE_ENCODER
  * produce: Properly cleanup on deactivate in all cases (kde#488687)
  * produce: Destroy PipeWireSourceStream on the right thread (kde#489434)
  * gitignore: add VS Code dir
  * mediamonitortest: start media session and create dummy output to test playback state
  * Use only non external only format modifiers
  * Drop implicit modifier shortcut
  * Use reserve to reserve space in list
  * update version for new release
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * sourcestream: Do not process null streams
  * pipewireproduce.cpp: Add guard to m_stream
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
  * sourcestream: make resilient against pipewire restarts
  * Add encoder using libopenh264 (kde#476187)
- Drop patches, now upstream:
  * 0001-Simpler-yet-more-useful-handling-of-KPIPEWIRE_FORCE_.patch
  * 0002-Add-encoder-using-libopenh264.patch
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to support libopenh264 for encoding
  (boo#1227461, kde#476187):
  * 0001-Simpler-yet-more-useful-handling-of-KPIPEWIRE_FORCE_.patch
  * 0002-Add-encoder-using-libopenh264.patch
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * produce: Properly cleanup on deactivate in all cases (kde#488687)
  * produce: Destroy PipeWireSourceStream on the right thread (kde#489434)
  * update version for new release
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
  * Use only non external only format modifiers
  * Drop implicit modifier shortcut
  * Use reserve to reserve space in list
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Too many changes to list here
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * update version for new release
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * fix version
  * update version for new release
  * encode: Only increase filtered frame count if frame was actually submitted
  * Fix nullptr check (kde#484620)
  * Generate presentation timestamps from std::chrono::steady_clock if SPA_META_Header is missing
  * Fix a minor coding style issue
  * Ignore buffers with SPA_META_HEADER_FLAG_CORRUPTED
  * Ignore chunk size of SPA_DATA_DmaBuf
  * typo
  * update version for new release
  * fix typo
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * fix typo
  * update version for new release
  * Don't set PipeWireSourceItem::enabled to true when the item becomes visible
  * Drop redundant isComponentComplete() checks
  * Remove redundant code
  * Mark PipeWireSourceItem as enabled after receiving a frame
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * fix version
  * update version for new release
  * bump version ahead of new release
  * cmake: Add missing " to unbreak the build
- Drop patches, now upstream:
  * 0001-cmake-Add-missing-to-unbreak-the-build.patch
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
- Add patch to fix build (wtf):
  * 0001-cmake-Add-missing-to-unbreak-the-build.patch
- Drop patch, no longer necessary:
  * 0001-Set-SOVERSION-to-6.patch
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * add back quotes
  * update version for new release
  * Drop defined but undeclared property
  * record: Make sure we also finalise streams that didn't even start
  * revert to version 6.0.0
  * set major version for soname
  * revert version number for bugfix release
  * Set the framework version in the project() call
  * bugfix release
  * Install kpipewire_version.h
* Tue Feb  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.1:
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.93.0:
  * Set the framework version in the project() call
  * Install kpipewire_version.h
- Add patch to set the SOVERSION correctly:
  * 0001-Set-SOVERSION-to-6.patch
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * source: Increase logging, drop redundant condition
  * Add missing cases to convertQImageFormatToAVPixelFormat
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat Jul  1 2023 Christophe Marin <christophe@krop.fr>
- Init kpipewire6
